| Title: | Computation and Visualization of Package Download Counts and Percentile Ranks |
|---|---|
| Description: | Compute and visualize package download counts and percentile ranks from Posit/RStudio's CRAN mirror. |
| Authors: | lindbrook [aut, cre] |
| Maintainer: | lindbrook <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.9.8.9005 |
| Built: | 2026-06-01 06:54:47 UTC |
| Source: | https://github.com/lindbrook/packagerank |
Compute and Visualize Package Download Counts and Percentile Ranks.
Download counts via cranDownloads().
Percentile ranks of download counts via packageRank() and packageLog().
Download count inflation filters.
Availability of results and logInfo().
Reverse lookup of counts, ranks and percentile ranks.
Data fixes and notes for logs and 'cranlogs' R package.
Discuss country code top-level domains, memoization and internet connection timeout problem.
Maintainer: lindbrook [email protected]
Authors:
lindbrook [email protected]
Useful links:
Report bugs at https://github.com/lindbrook/packageRank/issues
Download plot with annual and weekly data.
annualPlot(package = "packageRank", from = 2019, to = NULL, check.package = TRUE, pro.mode = FALSE, sunday.week = TRUE)annualPlot(package = "packageRank", from = 2019, to = NULL, check.package = TRUE, pro.mode = FALSE, sunday.week = TRUE)
package |
Character Package name, "R" (for R application) or NULL (for total CRAN package downloads). |
from |
Numeric or Integer Year. "yyyy". |
to |
Numeric or Integer. Year. "yyyy"; NULL uses current year. |
check.package |
Logical. Validate and "spell check" package. |
pro.mode |
Logical. |
sunday.week |
Logical. TRUE: week starts on Sunday. FALSE: week starts on Monday. |
Adapted from Vesuvius plot at https://github.com/nrennie/tidytuesday/blob/main/2025/2025-05-13/20250513.R
Annual/monthly package downloads from Bioconductor.
bioconductorDownloads(package = NULL, from = NULL, to = NULL, when = NULL, unit.observation = "month")bioconductorDownloads(package = NULL, from = NULL, to = NULL, when = NULL, unit.observation = "month")
package |
Character. Vector of package names. |
from |
Start date as |
to |
End date as |
when |
|
unit.observation |
"year" or "month". |
## Not run: # all packages bioconductorDownloads() # entire history bioconductorDownloads(package = "clusterProfiler") # year-to-date bioconductorDownloads(package = "clusterProfiler", when = "ytd") bioconductorDownloads(package = "clusterProfiler", when = "year-to-date") # last 12 months bioconductorDownloads(package = "clusterProfiler", when = "last-year") # from 2015 to current year bioconductorDownloads(package = "clusterProfiler", from = 2015) # 2010 through 2015 (yearly) bioconductorDownloads(package = "clusterProfiler", from = 2010, to = 2015, unit.observation = "year") # selected year (yearly) bioconductorDownloads(package = "clusterProfiler", from = 2015, to = 2015) # selected year (monthly) bioconductorDownloads(package = "clusterProfiler", from = "2015-01", to = "2015-12") # June 2014 through March 2015 bioconductorDownloads(package = "clusterProfiler", from = "2014-06", to = "2015-03") ## End(Not run)## Not run: # all packages bioconductorDownloads() # entire history bioconductorDownloads(package = "clusterProfiler") # year-to-date bioconductorDownloads(package = "clusterProfiler", when = "ytd") bioconductorDownloads(package = "clusterProfiler", when = "year-to-date") # last 12 months bioconductorDownloads(package = "clusterProfiler", when = "last-year") # from 2015 to current year bioconductorDownloads(package = "clusterProfiler", from = 2015) # 2010 through 2015 (yearly) bioconductorDownloads(package = "clusterProfiler", from = 2010, to = 2015, unit.observation = "year") # selected year (yearly) bioconductorDownloads(package = "clusterProfiler", from = 2015, to = 2015) # selected year (monthly) bioconductorDownloads(package = "clusterProfiler", from = "2015-01", to = "2015-12") # June 2014 through March 2015 bioconductorDownloads(package = "clusterProfiler", from = "2014-06", to = "2015-03") ## End(Not run)
From bioconductor
bioconductorRank(package = "monocle", date = "2019-01", count = "download")bioconductorRank(package = "monocle", date = "2019-01", count = "download")
package |
Character. Vector of package name(s). |
date |
Character. Date. yyyy-mm |
count |
Character. "ip" or "download". |
An R data frame.
## Not run: bioconductorRank(package = "cicero", date = "2019-09") ## End(Not run)## Not run: bioconductorRank(package = "cicero", date = "2019-09") ## End(Not run)
archive.pkg_verarchive.pkg_ver.filteredcran.pkg_vercran.pkg_ver.filtereddl.ctdl.ct2pkg.ctpkg.ct2oct.datacholera.dataggplot2.dataVR.datasmplsmpl.historiessmpl.archivesmpl.archive.historiesccode.ctcrosstab_2019_10_01percentilestop.n.oct2019top.n.jul2020download.countryoctober.downloadsjuly.downloadscran.pkgs.octarch.pkgs.octcran.pkgs.jularch.pkgs.julpkg.historyblog.datablog.data
A list with 29 elements.
From RStudio's CRAN Mirror http://cran-logs.rstudio.com/
countryDistribution(date = NULL, all.filters = FALSE, ip.filter = FALSE, sequence.filter = FALSE, size.filter = FALSE, small.filter = FALSE, version.filter = FALSE, memoization = TRUE, multi.core = FALSE)countryDistribution(date = NULL, all.filters = FALSE, ip.filter = FALSE, sequence.filter = FALSE, size.filter = FALSE, small.filter = FALSE, version.filter = FALSE, memoization = TRUE, multi.core = FALSE)
date |
Character. Date. "yyyy-mm-dd". NULL uses latest available log. |
all.filters |
Logical. Master switch for filters. |
ip.filter |
Logical. |
sequence.filter |
Logical. |
size.filter |
Logical. |
small.filter |
Logical. TRUE filters out downloads less than 1000 bytes. |
version.filter |
Logical. TRUE selects only most recent version. |
memoization |
Logical. Use memoization when downloading logs. |
multi.core |
Logical or Numeric. |
An R data frame.
all.filters = TRUE only enables IP and small filters.
From RStudio's CRAN Mirror http://cran-logs.rstudio.com/
countryPackage(country = "HK", date = NULL, all.filters = FALSE, ip.filter = FALSE, sequence.filter = FALSE, size.filter = FALSE, small.filter = FALSE, version.filter = FALSE, sort.count = TRUE, memoization = TRUE, multi.core = FALSE)countryPackage(country = "HK", date = NULL, all.filters = FALSE, ip.filter = FALSE, sequence.filter = FALSE, size.filter = FALSE, small.filter = FALSE, version.filter = FALSE, sort.count = TRUE, memoization = TRUE, multi.core = FALSE)
country |
Character. country abbreviation. |
date |
Character. Date. "yyyy-mm-dd". NULL uses latest available log. |
all.filters |
Logical. Master switch for filters. |
ip.filter |
Logical. |
sequence.filter |
Logical. |
size.filter |
Logical. |
small.filter |
Logical. TRUE filters out downloads less than 1000 bytes. |
version.filter |
Logical. TRUE selects only most recent version. |
sort.count |
Logical. Sort by download count. |
memoization |
Logical. Use memoization when downloading logs. |
multi.core |
Logical or Numeric. |
all.filters = TRUE only enables IP and small filters. "US" outlier 10 min with all filters!
Document code for blog graph.
countsRanks(package = "cholera", size.filter = FALSE)countsRanks(package = "cholera", size.filter = FALSE)
package |
Character. |
size.filter |
Logical. |
From Posit's CRAN Mirror http://cran-logs.rstudio.com/
cranDistribution(package = NULL, date = NULL, all.filters = FALSE, ip.filter = FALSE, small.filter = FALSE, memoization = TRUE, check.package = TRUE, multi.core = FALSE)cranDistribution(package = NULL, date = NULL, all.filters = FALSE, ip.filter = FALSE, small.filter = FALSE, memoization = TRUE, check.package = TRUE, multi.core = FALSE)
package |
Character. Vector of package name(s). NULL for all downloads, all of CRAN |
date |
Character. Date. "yyyy-mm-dd". NULL uses latest available log. |
all.filters |
Logical. Master switch for filters. |
ip.filter |
Logical. |
small.filter |
Logical. TRUE filters out downloads less than 1000 bytes. |
memoization |
Logical. Use memoization when downloading logs. |
check.package |
Logical. Validate and "spell check" package. |
multi.core |
Logical or Numeric. |
An R data frame.
Enhanced implementation of cranlogs::cran_downloads().
cranDownloads(package = NULL, when = NULL, from = NULL, to = NULL, check.package = TRUE, dev.mode = FALSE, fix.cranlogs = TRUE, pro.mode = FALSE)cranDownloads(package = NULL, when = NULL, from = NULL, to = NULL, check.package = TRUE, dev.mode = FALSE, fix.cranlogs = TRUE, pro.mode = FALSE)
package |
A character vector, the packages to query,
or |
when |
|
from |
Start date as |
to |
End date as |
check.package |
Logical. Validate and "spell check" package. |
dev.mode |
Logical. Use validatePackage0() to scrape CRAN. |
fix.cranlogs |
Logical. Use RStudio logs to fix 8 dates with duplicated data in 'cranlogs' results. |
pro.mode |
Logical. Faster but fewer checks/features. Closer to cranlogs::cran_downloads() but with cranDownloads()'s plot method. |
## Not run: cranDownloads(package = "HistData") cranDownloads(package = "HistData", when = "last-week") cranDownloads(package = "HistData", when = "last-month") # January 7 - 31, 2019 cranDownloads(package = "HistData", from = "2019-01-07", to = "2019-01-31") # February through March 2019 cranDownloads(package = "HistData", from = "2019-02", to = "2019-03") # 2024 year-to-date cranDownloads(package = "HistData", from = 2024) ## End(Not run)## Not run: cranDownloads(package = "HistData") cranDownloads(package = "HistData", when = "last-week") cranDownloads(package = "HistData", when = "last-month") # January 7 - 31, 2019 cranDownloads(package = "HistData", from = "2019-01-07", to = "2019-01-31") # February through March 2019 cranDownloads(package = "HistData", from = "2019-02", to = "2019-03") # 2024 year-to-date cranDownloads(package = "HistData", from = 2024) ## End(Not run)
Document code.
cranInflationPlot(dataset = "october")cranInflationPlot(dataset = "october")
dataset |
Character. "october" or "july" for October 2019 or July 2020. |
https://cran.r-project.org/mirrors.html
cranMirrors(description = FALSE)cranMirrors(description = FALSE)
description |
Logical. Mirror details. |
Compute Current Time in Selected Time Zone.
currentTime(tz = "Australia/Sydney")currentTime(tz = "Australia/Sydney")
tz |
Character. Local time zone. See OlsonNames() or use Sys.timezone(). |
Compute Downloads by Country Code.
downloadsCountry(month_cran_log, multi.core = FALSE)downloadsCountry(month_cran_log, multi.core = FALSE)
month_cran_log |
Object. |
multi.core |
Logical or Numeric. |
ip, small, sequence and size filters.
filteredDownloads(package = "HistData", date = NULL, all.filters = TRUE, ip.filter = FALSE, sequence.filter = FALSE, size.filter = FALSE, small.filter = FALSE, version.filter = FALSE, check.package = TRUE, memoization = TRUE)filteredDownloads(package = "HistData", date = NULL, all.filters = TRUE, ip.filter = FALSE, sequence.filter = FALSE, size.filter = FALSE, small.filter = FALSE, version.filter = FALSE, check.package = TRUE, memoization = TRUE)
package |
Character. Vector of package name(s). |
date |
Character. Date. "yyyy-mm-dd". NULL uses latest available log. |
all.filters |
Logical. Master switch for filters. |
ip.filter |
Logical. |
sequence.filter |
Logical. |
size.filter |
Logical. |
small.filter |
Logical. TRUE filters out downloads less than 1000 bytes. |
version.filter |
Logical. TRUE selects only most recent version. |
check.package |
Logical. Validate and "spell check" package. |
memoization |
Logical. Use memoization when downloading logs. |
Document code for blog graph.
inflationPlot(package = "cholera", filter = "size", legend.loc = "topleft")inflationPlot(package = "cholera", filter = "size", legend.loc = "topleft")
package |
Character. |
filter |
Character. Size, version, or size and version |
legend.loc |
Character. Location of legend. |
Document code.
inflationPlot2(dataset = "october", filter = "small", wed = FALSE, subtitle = TRUE, legend.loc = "topleft")inflationPlot2(dataset = "october", filter = "small", wed = FALSE, subtitle = TRUE, legend.loc = "topleft")
dataset |
Character. "october" or "july" for October 2019 or July 2020. |
filter |
Character. "small", "ip", or "ip.small". |
wed |
Logical. |
subtitle |
Logical. |
legend.loc |
Character. Location of legend. |
From RStudio's CRAN Mirror http://cran-logs.rstudio.com/
ipCount(date = NULL, memoization = TRUE, sort.count = TRUE)ipCount(date = NULL, memoization = TRUE, sort.count = TRUE)
date |
Character. Date. "yyyy-mm-dd". NULL uses latest available log. |
memoization |
Logical. Use memoization when downloading logs. |
sort.count |
Logical. Sort by download count. |
From RStudio's CRAN Mirror http://cran-logs.rstudio.com/
ipDownloads(date = NULL, memoization = TRUE)ipDownloads(date = NULL, memoization = TRUE)
date |
Character. Date. "yyyy-mm-dd". NULL uses latest available log. |
memoization |
Logical. Use memoization when downloading logs. |
From RStudio's CRAN Mirror http://cran-logs.rstudio.com/
ipPackage(ip = 10, date = NULL, all.filters = FALSE, ip.filter = FALSE, sequence.filter = FALSE, size.filter = FALSE, small.filter = FALSE, version.filter = FALSE, sort.count = TRUE, memoization = TRUE, multi.core = FALSE)ipPackage(ip = 10, date = NULL, all.filters = FALSE, ip.filter = FALSE, sequence.filter = FALSE, size.filter = FALSE, small.filter = FALSE, version.filter = FALSE, sort.count = TRUE, memoization = TRUE, multi.core = FALSE)
ip |
Numeric. ip_id. Positive integer. |
date |
Character. Date. "yyyy-mm-dd". NULL uses latest available log. |
all.filters |
Logical. Master switch for filters. |
ip.filter |
Logical. |
sequence.filter |
Logical. |
size.filter |
Logical. |
small.filter |
Logical. TRUE filters out downloads less than 1000 bytes. |
version.filter |
Logical. TRUE selects only most recent version. |
sort.count |
Logical. Sort by download count. |
memoization |
Logical. Use memoization when downloading logs. |
multi.core |
Logical or Numeric. |
all.filters = TRUE only enables IP and small filters. ip = 10 is a tw top-level domain on 2020-07-09.
Compute Local Time from Coordinated Universal Time (UTC/GMT).
localTime(time = "12:00", date = Sys.Date(), tz = Sys.timezone())localTime(time = "12:00", date = Sys.Date(), tz = Sys.timezone())
time |
Character. Local time "hh:mm" or "hh:mm:ss". |
date |
Character. Date "yyyy-mm-dd". |
tz |
Character. Local time zone. See OlsonNames() or use Sys.timezone(). |
RStudio CRAN Mirror Logs for previous day are posted at 17:00:00 UTC.
logDate(date = NULL, check.url = TRUE, tz = Sys.timezone(), upload.time = "17:00", warning.msg = TRUE, fix.date = TRUE)logDate(date = NULL, check.url = TRUE, tz = Sys.timezone(), upload.time = "17:00", warning.msg = TRUE, fix.date = TRUE)
date |
Character. Date of desired log |
check.url |
Logical. |
tz |
Character. Time zone. See OlsonNames(). |
upload.time |
Character. UTC upload time for logs "hh:mm" or "hh:mm:ss". |
warning.msg |
Logical. TRUE uses warning() if the function returns the date of the previous available log. |
fix.date |
Logical. Fix date when directly accessing RStudio logs. |
An R date object.
Also checks availability of Posit/RStudio logs and 'cranlogs' data.
logInfo(details = FALSE, tz = Sys.timezone(), upload.time = "17:00", check.days = 7)logInfo(details = FALSE, tz = Sys.timezone(), upload.time = "17:00", check.days = 7)
details |
Logical. Check available logs and results. |
tz |
Character. Local time zone. See OlsonNames() or use Sys.timezone(). |
upload.time |
Character. UTC upload time for logs "hh:mm" or "hh:mm:ss". |
check.days |
Numeric or Integer. Number of days back to check. |
August 25-26, 29-31 2025; September 1-2, 2025. 7 days.
missing.datesmissing.dates
An object of class Date of length 7.
Compute list of log files, 'lst', for packageVersionPercent().
monthlyLog(yr.mo = "2020-07")monthlyLog(yr.mo = "2020-07")
yr.mo |
Character. "yyyy-mm". |
This is computationally intensive; you're downloading 30 odd files that are each around 50 MB in size (and creating a ~1.5 GB file)! Parallelization not practical; multiple attempts to connect to website causes problems. Truncates in-progress/future dates to yesterday's date. Automatically takes care of leap days (e.g., monthlyLog("2020-02").
From RStudio's CRAN Mirror http://cran-logs.rstudio.com/
packageCountry(package = "cholera", date = NULL, all.filters = FALSE, ip.filter = FALSE, sequence.filter = FALSE, size.filter = FALSE, small.filter = FALSE, version.filter = FALSE, sort = TRUE, na.rm = FALSE, memoization = TRUE, check.package = TRUE, multi.core = FALSE)packageCountry(package = "cholera", date = NULL, all.filters = FALSE, ip.filter = FALSE, sequence.filter = FALSE, size.filter = FALSE, small.filter = FALSE, version.filter = FALSE, sort = TRUE, na.rm = FALSE, memoization = TRUE, check.package = TRUE, multi.core = FALSE)
package |
Character. Vector of package name(s). |
date |
Character. Date. "yyyy-mm-dd". NULL uses latest available log. |
all.filters |
Logical. Master switch for filters. |
ip.filter |
Logical. |
sequence.filter |
Logical. |
size.filter |
Logical. |
small.filter |
Logical. TRUE filters out downloads less than 1000 bytes. |
version.filter |
Logical. TRUE selects only most recent version. |
sort |
Logical. Sort by download count. |
na.rm |
Logical. Remove NAs. |
memoization |
Logical. Use memoization when downloading logs. |
check.package |
Logical. Validate and "spell check" package. |
multi.core |
Logical or Numeric. |
Date and version of all publications.
packageHistory(package = "cholera", check.package = TRUE)packageHistory(package = "cholera", check.package = TRUE)
package |
Character. Vector of package names (including "R"). |
check.package |
Logical. Validate and "spell check" package. |
From RStudio's CRAN Mirror http://cran-logs.rstudio.com/
packageLog(package = "cholera", date = NULL, all.filters = FALSE, ip.filter = FALSE, sequence.filter = FALSE, size.filter = FALSE, small.filter = FALSE, version.filter = FALSE, memoization = TRUE, check.package = TRUE)packageLog(package = "cholera", date = NULL, all.filters = FALSE, ip.filter = FALSE, sequence.filter = FALSE, size.filter = FALSE, small.filter = FALSE, version.filter = FALSE, memoization = TRUE, check.package = TRUE)
package |
Character. Vector of package name(s). |
date |
Character. Date. "yyyy-mm-dd". NULL uses latest available log. |
all.filters |
Logical. Master switch for filters. |
ip.filter |
Logical. |
sequence.filter |
Logical. |
size.filter |
Logical. |
small.filter |
Logical. TRUE filters out downloads less than 1000 bytes. |
version.filter |
Logical. TRUE selects only most recent version. |
memoization |
Logical. Use memoization when downloading logs. |
check.package |
Logical. Validate and "spell check" package. |
An R data frame.
From Posit/RStudio's CRAN Mirror (CDN) http://cran-logs.rstudio.com/
packageRank(package = "packageRank", date = NULL, all.filters = FALSE, ip.filter = FALSE, small.filter = FALSE, memoization = TRUE, check.package = TRUE, rank.ties = TRUE, multi.core = FALSE)packageRank(package = "packageRank", date = NULL, all.filters = FALSE, ip.filter = FALSE, small.filter = FALSE, memoization = TRUE, check.package = TRUE, rank.ties = TRUE, multi.core = FALSE)
package |
Character. Vector of package name(s). |
date |
Character. Date. "yyyy-mm-dd". NULL uses latest available log. |
all.filters |
Logical. Master switch for filters. |
ip.filter |
Logical. |
small.filter |
Logical. TRUE filters out downloads less than 1000 bytes. |
memoization |
Logical. Use memoization when downloading logs. |
check.package |
Logical. Validate and "spell check" package. |
rank.ties |
Logical. TRUE uses competition ranking ("1224") for ties. FALSE uses nominal rank (no ties). |
multi.core |
Logical or Numeric. |
An R data frame.
## Not run: packageRank(package = "cholera", date = "2020-01-01") packageRank(package = c("h2o", "Rcpp", "rstan"), date = "2020-01-01") ## End(Not run)## Not run: packageRank(package = "cholera", date = "2020-01-01") packageRank(package = c("h2o", "Rcpp", "rstan"), date = "2020-01-01") ## End(Not run)
packageRank::blog.data or recompute random sample of packages.
packageVersionPercent(lst, yr.mo = "2020-07", multi.core = FALSE)packageVersionPercent(lst, yr.mo = "2020-07", multi.core = FALSE)
lst |
Object. List of CRAN download logs data frames. Use monthlyLog(). |
yr.mo |
Character. "yyyy-mo". packageVersionsPercent(NULL, yr.mo) |
multi.core |
Logical or Numeric. |
## Not run: # To resample and recompute, set lst to NULL, specify a yr.mo: packageVersionPercent(NULL, yr.mo = "2020-07") Otherwise, you must provide a pre-computed lst of logs. ## End(Not run)## Not run: # To resample and recompute, set lst to NULL, specify a yr.mo: packageVersionPercent(NULL, yr.mo = "2020-07") Otherwise, you must provide a pre-computed lst of logs. ## End(Not run)
Plot method for bioconductorDownloads().
## S3 method for class 'bioconductorDownloads' plot(x, graphics = NULL, count = "download", cumulative = FALSE, points = "auto", smooth = FALSE, f = 2/3, span = 3/4, se = FALSE, log.y = FALSE, r.version = FALSE, same.xy = TRUE, multi.plot = FALSE, legend.loc = "topleft", ...)## S3 method for class 'bioconductorDownloads' plot(x, graphics = NULL, count = "download", cumulative = FALSE, points = "auto", smooth = FALSE, f = 2/3, span = 3/4, se = FALSE, log.y = FALSE, r.version = FALSE, same.xy = TRUE, multi.plot = FALSE, legend.loc = "topleft", ...)
x |
object. |
graphics |
Character. NULL, "base" or "ggplot2". |
count |
Character. "download" or "ip". |
cumulative |
Logical. Use cumulative counts. |
points |
Character of Logical. Plot points. "auto", TRUE, FALSE. "auto" for bioconductorDownloads(unit.observation = "month") with 24 or fewer months, points are plotted. |
smooth |
Logical. Add stats::lowess smoother. |
f |
Numeric. smoother window for stats::lowess(). For graphics = "base" only; c.f. stats::lowess(f) |
span |
Numeric. Smoothing parameter for geom_smooth(); c.f. stats::loess(span). |
se |
Logical. Works only with graphics = "ggplot2". |
log.y |
Logical. Logarithm of package downloads. |
r.version |
Logical. Add R release dates. |
same.xy |
Logical. Use same scale for multiple packages when graphics = "base". |
multi.plot |
Logical. Plot all data in a single window frame. |
legend.loc |
Character. |
... |
Additional plotting parameters. |
## Not run: plot(bioconductorDownloads()) plot(bioconductorDownloads(package = "graph")) plot(bioconductorDownloads(package = "graph", from = 2010, to = 2015)) plot(bioconductorDownloads(package = "graph", from = "2014-06", to = "2015-03")) plot(bioconductorDownloads(package = c("graph", "IRanges", "S4Vectors"), from = 2018)) ## End(Not run)## Not run: plot(bioconductorDownloads()) plot(bioconductorDownloads(package = "graph")) plot(bioconductorDownloads(package = "graph", from = 2010, to = 2015)) plot(bioconductorDownloads(package = "graph", from = "2014-06", to = "2015-03")) plot(bioconductorDownloads(package = c("graph", "IRanges", "S4Vectors"), from = 2018)) ## End(Not run)
Plot method for bioconductorRank().
## S3 method for class 'bioconductorRank' plot(x, graphics = NULL, log.y = TRUE, ...)## S3 method for class 'bioconductorRank' plot(x, graphics = NULL, log.y = TRUE, ...)
x |
An object of class "bioconductor_rank" created by |
graphics |
Character. "base" or "ggplot2". |
log.y |
Logical. Logarithm of package downloads. |
... |
Additional plotting parameters. |
A base R or ggplot2 plot.
Plot method for countryDistribution().
## S3 method for class 'countryDistribution' plot(x, N = 10, ...)## S3 method for class 'countryDistribution' plot(x, N = 10, ...)
x |
An object of class "countryDistribution" created by |
N |
Integer. Top N countries. |
... |
Additional plotting parameters. |
Plot method for countsRanks().
## S3 method for class 'countsRanks' plot(x, ...)## S3 method for class 'countsRanks' plot(x, ...)
x |
object. |
... |
Additional plotting parameters. |
Plot method for cranDistribution().
## S3 method for class 'cranDistribution' plot(x, ...)## S3 method for class 'cranDistribution' plot(x, ...)
x |
An object of class "cranDistribution" created by |
... |
Additional plotting parameters. |
A base R plot.
Plot method for cranDownloads().
## S3 method for class 'cranDownloads' plot(x, statistic = "count", graphics = "auto", points = "auto", log.y = FALSE, smooth = FALSE, se = FALSE, f = 1/3, span = 3/4, package.version = FALSE, axis.package = NULL, axis.package.version = FALSE, r.version = FALSE, multi.plot = FALSE, same.xy = TRUE, legend.location = "topleft", ip.legend.location = "topright", r.total = FALSE, dev.mode = FALSE, unit.observation = "day", chatgpt = "line", weekend = FALSE, multi.core = FALSE, ...)## S3 method for class 'cranDownloads' plot(x, statistic = "count", graphics = "auto", points = "auto", log.y = FALSE, smooth = FALSE, se = FALSE, f = 1/3, span = 3/4, package.version = FALSE, axis.package = NULL, axis.package.version = FALSE, r.version = FALSE, multi.plot = FALSE, same.xy = TRUE, legend.location = "topleft", ip.legend.location = "topright", r.total = FALSE, dev.mode = FALSE, unit.observation = "day", chatgpt = "line", weekend = FALSE, multi.core = FALSE, ...)
x |
object. |
statistic |
Character. "count" or "cumulative". |
graphics |
Character. "auto", "base" or "ggplot2". |
points |
Character of Logical. Plot points. "auto", TRUE, FALSE. |
log.y |
Logical. Logarithm of package downloads. |
smooth |
Logical. Add smoother. |
se |
Logical. Works only with graphics = "ggplot2". |
f |
Numeric. smoother window for stats::lowess(). For graphics = "base" only; c.f. stats::lowess(f) |
span |
Numeric. Smoothing parameter for geom_smooth(); c.f. stats::loess(span). |
package.version |
Logical or "line". Add package release dates and vertical lines. |
axis.package |
Character. Add one additional package version to axis. |
axis.package.version |
Logical or "line". Add package release dates and vertical lines. |
r.version |
Logical or "line". Add R release dates and vertical lines. |
multi.plot |
Logical. Multiple package data in single plot. |
same.xy |
Logical. Use same scale for multiple packages when graphics = "base". |
legend.location |
Character. |
ip.legend.location |
Character. Location of in-progress legend. |
r.total |
Logical. |
dev.mode |
Logical. Use packageHistory0() to scrape CRAN. |
unit.observation |
Character. "year", "month", "week", or "day". |
chatgpt |
Logical or "line". Add intitial availability date and vertical line for ChatGPT. |
weekend |
Logical. Highlight weekends (pch = 1) when unit.observation = "day". |
multi.core |
Logical or Numeric. |
... |
Additional plotting parameters. |
A base R or ggplot2 plot.
## Not run: plot(cranDownloads(package = c("Rcpp", "rlang", "data.table"))) plot(cranDownloads(package = c("Rcpp", "rlang", "data.table"), when = "last-month")) plot(cranDownloads(package = "R", from = "2020-01-01", to = "2020-01-01")) plot(cranDownloads(package = "R", from = 2020)) ## End(Not run)## Not run: plot(cranDownloads(package = c("Rcpp", "rlang", "data.table"))) plot(cranDownloads(package = c("Rcpp", "rlang", "data.table"), when = "last-month")) plot(cranDownloads(package = "R", from = "2020-01-01", to = "2020-01-01")) plot(cranDownloads(package = "R", from = 2020)) ## End(Not run)
Plot method for packageDistribution().
## S3 method for class 'packageDistribution' plot(x, ...)## S3 method for class 'packageDistribution' plot(x, ...)
x |
An object of class "packageDistribution" created by |
... |
Additional plotting parameters. |
Plot method for packageLog().
## S3 method for class 'packageLog' plot(x, type = "1D", unit.observation = "second", smooth = FALSE, points = TRUE, same.xy = TRUE, local.timezone = TRUE, ...)## S3 method for class 'packageLog' plot(x, type = "1D", unit.observation = "second", smooth = FALSE, points = TRUE, same.xy = TRUE, local.timezone = TRUE, ...)
x |
Object. |
type |
Character. "1D" or "2D". |
unit.observation |
Character. "second", "minute", or "hour". |
smooth |
Logical. Add smoother. |
points |
Logical. For "hour" and "minute" in 2D plots. |
same.xy |
Logical. Use same scale for multiple packages for type = "2D". |
local.timezone |
Logical or Character. TRUE for Sys.timezone(). See OlsonNames() for other time zones. |
... |
Additional parameters. |
Plot method for packageRank() and packageRank0().
## S3 method for class 'packageRank' plot(x, graphics = NULL, log.y = TRUE, ...)## S3 method for class 'packageRank' plot(x, graphics = NULL, log.y = TRUE, ...)
x |
An object of class "packageRank" created by |
graphics |
Character. "base" or "ggplot2". |
log.y |
Logical. Logarithm of package downloads. |
... |
Additional plotting parameters. |
A base R or ggplot2 plot.
## Not run: plot(packageRank(package = "HistData", date = "2020-01-01")) plot(packageRank(package = c("h2o", "Rcpp", "rstan"), date = "2020-01-01")) ## End(Not run)## Not run: plot(packageRank(package = "HistData", date = "2020-01-01")) plot(packageRank(package = c("h2o", "Rcpp", "rstan"), date = "2020-01-01")) ## End(Not run)
Plot method for packageVersionPercent().
## S3 method for class 'packageVersionPercent' plot(x, ...)## S3 method for class 'packageVersionPercent' plot(x, ...)
x |
An object of class "packageVersionPercent". |
... |
Additional plotting parameters. |
Plot method for weeklyDownloads().
## S3 method for class 'weeklyDownloads' plot(x, statistic = "percent", aggregation = "day", typical.value = "mean", nrow = 3L, ...)## S3 method for class 'weeklyDownloads' plot(x, statistic = "percent", aggregation = "day", typical.value = "mean", nrow = 3L, ...)
x |
object. |
statistic |
Character. "count" or "percent". |
aggregation |
Character. "week" or "day". |
typical.value |
Character. "mean" or "median". |
nrow |
Numeric. Number of rows for ggplot2 facets. |
... |
Additional plotting parameters. |
## Not run: plot(weeklyDownloads()) plot(weeklyDownloads(n = 9), aggregation = "week") ## End(Not run)## Not run: plot(weeklyDownloads()) plot(weeklyDownloads(n = 9), aggregation = "week") ## End(Not run)
Plot Compute Downloads by Country Code.
plotDownloadsCountry()plotDownloadsCountry()
Plot Top N Downloads by Country Code.
plotTopCountryCodes(dataset = "october", second.place = FALSE)plotTopCountryCodes(dataset = "october", second.place = FALSE)
dataset |
Character. |
second.place |
Logical. Annotate second place country. |
Print method for bioconductorDownloads().
## S3 method for class 'bioconductorDownloads' print(x, ...)## S3 method for class 'bioconductorDownloads' print(x, ...)
x |
object. |
... |
Additional parameters. |
Print method for bioconductorRank().
## S3 method for class 'bioconductorRank' print(x, ...)## S3 method for class 'bioconductorRank' print(x, ...)
x |
An object of class "bioconductor_rank" created by |
... |
Additional parameters. |
Print method for countryDistribution().
## S3 method for class 'countryDistribution' print(x, N = 10, ...)## S3 method for class 'countryDistribution' print(x, N = 10, ...)
x |
object. |
N |
Integer. Top N countries. |
... |
Additional parameters. |
Print method for cranDistribution().
## S3 method for class 'cranDistribution' print(x, top.n = 20, ...)## S3 method for class 'cranDistribution' print(x, top.n = 20, ...)
x |
object. |
top.n |
Numeric or Integer. |
... |
Additional parameters. |
Print method for cranDownloads().
## S3 method for class 'cranDownloads' print(x, ...)## S3 method for class 'cranDownloads' print(x, ...)
x |
object. |
... |
Additional parameters. |
Print method for packageDistribution().
## S3 method for class 'packageDistribution' print(x, top.n = 20, ...)## S3 method for class 'packageDistribution' print(x, top.n = 20, ...)
x |
An object of class "packageDistribution" created by |
top.n |
Numeric or Integer. |
... |
Additional parameters. |
Print method for packageLog().
## S3 method for class 'packageLog' print(x, ...)## S3 method for class 'packageLog' print(x, ...)
x |
object. |
... |
Additional parameters. |
Print method for packageRank().
## S3 method for class 'packageRank' print(x, ...)## S3 method for class 'packageRank' print(x, ...)
x |
An object of class "packageRank" created by |
... |
Additional parameters. |
Query download count.
queryCount(count = 1, date = NULL, all.filters = FALSE, ip.filter = FALSE, small.filter = FALSE, memoization = TRUE, multi.core = FALSE)queryCount(count = 1, date = NULL, all.filters = FALSE, ip.filter = FALSE, small.filter = FALSE, memoization = TRUE, multi.core = FALSE)
count |
Numeric or Integer. whole number. |
date |
Character. Date. "yyyy-mm-dd". NULL uses latest available log. |
all.filters |
Logical. Master switch for filters. |
ip.filter |
Logical. |
small.filter |
Logical. TRUE filters out downloads less than 1000 bytes. |
memoization |
Logical. Use memoization when downloading logs. |
multi.core |
Logical or Numeric. |
An R data frame.
Query package name.
queryPackage(package = "packageRank", date = NULL, all.filters = FALSE, ip.filter = FALSE, small.filter = FALSE, memoization = TRUE, check.package = TRUE, multi.core = FALSE)queryPackage(package = "packageRank", date = NULL, all.filters = FALSE, ip.filter = FALSE, small.filter = FALSE, memoization = TRUE, check.package = TRUE, multi.core = FALSE)
package |
Character.. |
date |
Character. Date. "yyyy-mm-dd". NULL uses latest available log. |
all.filters |
Logical. Master switch for filters. |
ip.filter |
Logical. |
small.filter |
Logical. TRUE filters out downloads less than 1000 bytes. |
memoization |
Logical. Use memoization when downloading logs. |
check.package |
Logical. Validate and "spell check" package. |
multi.core |
Logical or Numeric. |
An R data frame.
Percentile-rank query.
queryPercentile(percentile = 50, lo = NULL, hi = NULL, date = NULL, all.filters = FALSE, ip.filter = FALSE, small.filter = FALSE, memoization = TRUE, multi.core = FALSE)queryPercentile(percentile = 50, lo = NULL, hi = NULL, date = NULL, all.filters = FALSE, ip.filter = FALSE, small.filter = FALSE, memoization = TRUE, multi.core = FALSE)
percentile |
Numeric. 50 uses median(). |
lo |
Integer. |
hi |
Integer |
date |
Character. Date. "yyyy-mm-dd". NULL uses latest available log. |
all.filters |
Logical. Master switch for filters. |
ip.filter |
Logical. |
small.filter |
Logical. TRUE filters out downloads less than 1000 bytes. |
memoization |
Logical. Use memoization when downloading logs. |
multi.core |
Logical or Numeric. |
An R data frame.
Rank query.
queryRank(rank = 1, rank.ties = FALSE, date = NULL, all.filters = FALSE, ip.filter = FALSE, small.filter = FALSE, memoization = TRUE, multi.core = FALSE)queryRank(rank = 1, rank.ties = FALSE, date = NULL, all.filters = FALSE, ip.filter = FALSE, small.filter = FALSE, memoization = TRUE, multi.core = FALSE)
rank |
Numeric or Integer. |
rank.ties |
Logical. TRUE uses ties. FALSE does not. |
date |
Character. Date. "yyyy-mm-dd". NULL uses latest available log. |
all.filters |
Logical. Master switch for filters. |
ip.filter |
Logical. |
small.filter |
Logical. TRUE filters out downloads less than 1000 bytes. |
memoization |
Logical. Use memoization when downloading logs. |
multi.core |
Logical or Numeric. |
An R data frame.
October 6-8, 2012; October 11, 2012; December 26-28; and January 1, 20113.
rstudio.logsrstudio.logs
datetimesizer_versionr_archr_ospackageversioncountryip_idSummary method for bioconductorDownloads().
## S3 method for class 'bioconductorDownloads' summary(object, ...)## S3 method for class 'bioconductorDownloads' summary(object, ...)
object |
Object. |
... |
Additional parameters. |
Summary method for bioconductorRank().
## S3 method for class 'bioconductorRank' summary(object, ...)## S3 method for class 'bioconductorRank' summary(object, ...)
object |
Object. An object of class "bioconductor_rank" created by |
... |
Additional parameters. |
This is useful for directly accessing the data frame.
Five number (+ mean) summary of download count distribution
## S3 method for class 'cranDistribution' summary(object, ...)## S3 method for class 'cranDistribution' summary(object, ...)
object |
An object of class "cranDistribution" created by |
... |
Additional plotting parameters. |
A base R vector
Summary method for cranDownloads().
## S3 method for class 'cranDownloads' summary(object, ...)## S3 method for class 'cranDownloads' summary(object, ...)
object |
Object. |
... |
Additional parameters. |
This is useful for directly accessing the data frame.
Five number (+ mean) summary of download count distribution
## S3 method for class 'packageDistribution' summary(object, ...)## S3 method for class 'packageDistribution' summary(object, ...)
object |
An object of class "packageDistribution" created by |
... |
Additional plotting parameters. |
A base R vector
Summary method for packageRank().
## S3 method for class 'packageRank' summary(object, ...)## S3 method for class 'packageRank' summary(object, ...)
object |
Object. An object of class "packageRank" created by |
... |
Additional parameters. |
This is useful for directly accessing the data frame.
Compute Top N Downloads by Country Code.
topCountryCodes(month_cran_log, top.n = 5L, multi.core = FALSE)topCountryCodes(month_cran_log, top.n = 5L, multi.core = FALSE)
month_cran_log |
Object. |
top.n |
Integer. |
multi.core |
Logical or Numeric. |
Compute Coordinated Universal Time (UTC/GMT) for Your Local Time.
utc()utc()
Compute Coordinated Universal Time (UTC/GMT) for Specified Local Time.
utc0(date = "2020-01-01", time = "12:00:00", tz = "Europe/Vienna")utc0(date = "2020-01-01", time = "12:00:00", tz = "Europe/Vienna")
date |
Character. Date "yyyy-mm-dd". |
time |
Character. Local time "hh:mm" or "hh:mm:ss". |
tz |
Character. Local time zone. See OlsonNames() or use Sys.timezone(). |
From RStudio's CRAN Mirror http://cran-logs.rstudio.com/
weeklyDownloads(start.yr = 2013, n = 50, multi.core = FALSE)weeklyDownloads(start.yr = 2013, n = 50, multi.core = FALSE)
start.yr |
Numeric or Integer. |
n |
Numeric or Integer. Number of weeks (samples). |
multi.core |
Logical or Numeric. |